@@ -41,11 +41,11 @@ void StatisticsStrategy::run(const Ideal& ideal) {
 }
 
 bool StatisticsStrategy::processSlice
-(TaskEngine& tasks, auto_ptr<Slice> slice) {
+(TaskEngine& tasks, unique_ptr<Slice> slice) {
   _internalTracker.preliminaryRecord(*slice);
   _leafTracker.preliminaryRecord(*slice);
 
-  bool wasBaseCase = _strategy->processSlice(tasks, slice);
+  bool wasBaseCase = _strategy->processSlice(tasks, std::move(slice));
 
   if (wasBaseCase)
     _leafTracker.commitRecord();
@@ -67,8 +67,8 @@ bool StatisticsStrategy::getUseSimplification() const {
   return _strategy->getUseSimplification();
 }
 
-void StatisticsStrategy::freeSlice(auto_ptr<Slice> slice) {
-  _strategy->freeSlice(slice);
+void StatisticsStrategy::freeSlice(unique_ptr<Slice> slice) {
+  _strategy->freeSlice(std::move(slice));
 }
 
 StatisticsStrategy::StatTracker::StatTracker(const string& title):
