@@ -27,7 +27,13 @@
 #include "IdealFacade.h"
 #include "SliceParams.h"
 
-const char* const frobby_version = "0.9.5";
+/* also increment the version number in:
+   - CMakeLists.txt
+   - doc/doxygen.conf
+   - doc/manual.tex
+   - test/messages/help-noparam.err
+   and update the library version as outlined in Makefile */
+const char* const frobby_version = "0.9.6";
 
 class ConsumerWrapper {
 protected:
